---
title: <span class="badge builder"></span> HideableFieldConfig
---
# <span class="badge builder"></span> HideableFieldConfig

## Constructor

```python
HideableFieldConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.HideableFieldConfig
```

### <span class="badge object-method"></span> hide_from

```python
def hide_from(hide_from: cogbuilder.Builder[common.HideSeriesConfig]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [HideableFieldConfig](./object-HideableFieldConfig.md)
